import type { AllQueryBuilderMethodArgs } from "../types";
declare class QueryStringBuilder {
    private queryFields;
    /**
     * The function takes an object as an argument, converts it to a query string, and assigns it to
     * the queryFields.filter property
     * @param filter - AllQueryBuilderMethodArgs['filter']
     * @returns The query builder object itself.
     */
    filter(filter: AllQueryBuilderMethodArgs['filter']): this;
    /**
     * The function takes an object of type `AllQueryBuilderMethodArgs['include']` and returns a `this`
     * of type `AllQueryBuilderMethodArgs['include']`
     * @param include - AllQueryBuilderMethodArgs['include']
     * @returns The query builder object itself.
     */
    include(include: AllQueryBuilderMethodArgs['include']): this;
    /**
     * This function takes an array of strings and joins them together with a comma, then assigns the
     * result to a property on the object that called the function.
     * @param select - string[]
     * @returns The query builder object itself.
     */
    select(select: AllQueryBuilderMethodArgs['select']): this;
    /**
     * The function takes an array of strings and joins them together with a comma
     * @param sort - string[]
     * @returns The queryFields object.
     */
    sort(sort: AllQueryBuilderMethodArgs['sort']): this;
    /**
     * This function takes an object with two properties, limit and page, and sets the queryFields
     * object's limit and page properties to the values of the limit and page properties of the
     * paginate object.
     * @param paginate - AllQueryBuilderMethodArgs['paginate']
     * @returns The query builder instance.
     */
    paginate(paginate: AllQueryBuilderMethodArgs['paginate']): this;
    /**
     * "If the argument is not null, then call the corresponding method on the query builder."
     *
     * The above function is a good example of how to use the Partial type.
     * @param  - Partial<AllQueryBuilderMethodArgs>
     * @returns The QueryBuilder instance.
     */
    all({ filter, include, paginate, select, sort }: Partial<AllQueryBuilderMethodArgs>): this;
    /**
     * It takes an object, converts it to a string, and then returns the string
     * @returns The query string
     */
    build(): string;
}
export default QueryStringBuilder;
