"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.queryParseMiddleware = exports.parseValue = exports.parseBoolean = exports.parseNumber = exports.parseArray = exports.parseObject = exports.isArray = exports.isBoolean = exports.isNumber = exports.isObject = void 0;
/**
 * It returns true if the value passed to it is an object, and false if it's not
 * @param {any} val - any
 * @returns The constructor of the object.
 */
const isObject = (val) => {
    return val.constructor === Object;
};
exports.isObject = isObject;
/**
 * If the value is not a number, then it's not a number.
 * @param {any} val - any - The value to check
 * @returns A function that takes a parameter and returns a boolean.
 */
const isNumber = (val) => {
    return !isNaN(parseFloat(val)) && isFinite(val);
};
exports.isNumber = isNumber;
/**
 * It returns true if the value is a string that is either 'true' or 'false'
 * @param {any} val - any
 * @returns A function that takes a parameter and returns a boolean.
 */
const isBoolean = (val) => {
    return val === 'false' || val === 'true';
};
exports.isBoolean = isBoolean;
/**
 * If the value is an array, return true, otherwise return false.
 * @param {any} val - any
 * @returns A function that takes a parameter and returns a boolean.
 */
const isArray = (val) => {
    return Array.isArray(val);
};
exports.isArray = isArray;
/**
 * It takes an object, and returns an object with the same keys, but with the values parsed
 * @param {ParsedQs} obj - ParsedQs - The object to parse.
 * @returns An object with the key and value of the parsed object.
 */
const parseObject = (obj) => {
    var result = {};
    var key, val;
    for (key in obj) {
        val = (0, exports.parseValue)(obj[key]);
        if (val !== null)
            result = { [key]: val }; // ignore null values
    }
    return result;
};
exports.parseObject = parseObject;
/**
 * It takes an array of strings and returns an array of objects.
 * @param {string | any[]} arr - string | any[]
 * @returns An array of parsed values.
 */
const parseArray = (arr) => {
    var result = [];
    for (var i = 0; i < arr.length; i++) {
        result[i] = (0, exports.parseValue)(arr[i]);
    }
    return result;
};
exports.parseArray = parseArray;
/**
 * It takes a value, converts it to a number, and returns it.
 * @param {any} val - any - The value to be parsed.
 * @returns A function that takes a parameter and returns a number.
 */
const parseNumber = (val) => {
    return Number(val);
};
exports.parseNumber = parseNumber;
/**
 * It returns true if the value is the string 'true', otherwise it returns false
 * @param {any} val - any - The value to parse.
 * @returns A function that takes a parameter and returns a boolean.
 */
const parseBoolean = (val) => {
    return val === 'true';
};
exports.parseBoolean = parseBoolean;
/**
 * If the value is a boolean, array, object, or number, parse it. Otherwise, return the value.
 * @param {any} val - any
 * @returns the value of the variable val.
 */
const parseValue = (val) => {
    if (typeof val === 'undefined' || val === '') {
        return null;
    }
    else if ((0, exports.isBoolean)(val)) {
        return (0, exports.parseBoolean)(val);
    }
    else if ((0, exports.isArray)(val)) {
        return (0, exports.parseArray)(val);
    }
    else if ((0, exports.isObject)(val)) {
        return (0, exports.parseObject)(val);
    }
    else if ((0, exports.isNumber)(val)) {
        return (0, exports.parseNumber)(val);
    }
    else {
        return val;
    }
};
exports.parseValue = parseValue;
/**
 * It takes a query object, parses it, and then returns a new object with the parsed values
 * @returns A function that takes in a request and a response and a next function.
 */
const queryParseMiddleware = () => {
    return (req, _res, next) => {
        req.query = (0, exports.parseObject)(req.query);
        next();
    };
};
exports.queryParseMiddleware = queryParseMiddleware;
//# sourceMappingURL=query-string-parser.js.map